diff --git a/NOTES b/NOTES
index f65ad42..fdf36fe 100644
--- a/NOTES
+++ b/NOTES
@@ -572,4 +572,15 @@ we need.
May 25, 2011
-About to make modules work. Need to make sure exports can rename names.
\ No newline at end of file
+About to make modules work. Need to make sure exports can rename names.
+
+
+
+----------------------------------------------------------------------
+
+What's currently preventing racket/base?
+
+Nan, INF Numbers, Regular expressions, keywords, byte strings,
+character literals
+
+Missing #%paramz module
\ No newline at end of file
diff --git a/js-assembler/get-runtime.rkt b/js-assembler/get-runtime.rkt
index 25180ee..c1a0fe5 100644
--- a/js-assembler/get-runtime.rkt
+++ b/js-assembler/get-runtime.rkt
@@ -9,11 +9,22 @@
(provide/contract [get-runtime (-> string?)])
+(define-runtime-path jquery.js "runtime-src/jquery-1.6.1.min.js")
(define-runtime-path runtime.js "mini-runtime.js")
-(define text (call-with-input-file runtime.js
- (lambda (ip)
- (port->string ip))))
+
+(define (path->string p)
+ (call-with-input-file p
+ (lambda (ip)
+ (port->string ip))))
+
+
+(define text (string-append
+ (path->string jquery.js)
+ (path->string runtime.js)))
+
+
+
(define (get-runtime)
text)
\ No newline at end of file
diff --git a/js-assembler/package.rkt b/js-assembler/package.rkt
index c66ac85..fb42131 100644
--- a/js-assembler/package.rkt
+++ b/js-assembler/package.rkt
@@ -69,31 +69,50 @@
-
;; package-standalone-xhtml: X output-port -> void
(define (package-standalone-xhtml source-code op)
- (fprintf op #<
-
-
-
- Example
-
-
+
+
+
+EOF
+)
+
+
+(define *invoke-main-module-text*
+ #<\n\n\n
diff --git a/js-assembler/mini-runtime.js b/js-assembler/mini-runtime.js
index cd12e08..5b358f6 100644
--- a/js-assembler/mini-runtime.js
+++ b/js-assembler/mini-runtime.js
@@ -65,47 +65,50 @@
this.control = []; // Arrayof (U Frame CallFrame PromptFrame)
this.running = false;
this.modules = {}; // String -> ModuleRecord
- this.params = { 'currentDisplayer': function(v) {},
-
- 'currentOutputPort': new StandardOutputPort(),
- 'currentSuccessHandler': function(MACHINE) {},
- 'currentErrorHandler': function(MACHINE, exn) {},
-
- 'currentNamespace': {},
-
- // These parameters control how often
- // control yields back to the browser
- // for response. The implementation is a
- // simple PID controller.
- //
- // To tune this, adjust desiredYieldsPerSecond.
- // Do no touch numBouncesBeforeYield or
- // maxNumBouncesBeforeYield, because those
- // are adjusted automatically by the
- // recomputeMaxNumBouncesBeforeYield
- // procedure.
- 'desiredYieldsPerSecond': 5,
- 'numBouncesBeforeYield': 2000, // self-adjusting
- 'maxNumBouncesBeforeYield': 2000, // self-adjusting
+ this.params = {
-
+ // currentDisplayer: DomNode -> Void
+ // currentDisplayer is responsible for displaying to the browser.
+ 'currentDisplayer': function(v) {
+ $(document.body).append(v);
+ },
+
+ 'currentOutputPort': new StandardOutputPort(),
+ 'currentSuccessHandler': function(MACHINE) {},
+ 'currentErrorHandler': function(MACHINE, exn) {},
+
+ 'currentNamespace': {},
+
+ // These parameters control how often
+ // control yields back to the browser
+ // for response. The implementation is a
+ // simple PID controller.
+ //
+ // To tune this, adjust desiredYieldsPerSecond.
+ // Do no touch numBouncesBeforeYield or
+ // maxNumBouncesBeforeYield, because those
+ // are adjusted automatically by the
+ // recomputeMaxNumBouncesBeforeYield
+ // procedure.
+ 'desiredYieldsPerSecond': 5,
+ 'numBouncesBeforeYield': 2000, // self-adjusting
+ 'maxNumBouncesBeforeYield': 2000, // self-adjusting
-
- 'current-print': new Closure(
- function(MACHINE) {
- var elt = MACHINE.env.pop();
- var outputPort =
- MACHINE.params.currentOutputPort;
- if (elt !== undefined) {
- outputPort.write(MACHINE, elt);
- outputPort.write(MACHINE, "\n");
- }
- var frame = MACHINE.control.pop();
- return frame.label(MACHINE);
- },
- 1,
- [],
- "printer")
+ 'current-print': new Closure(
+ function(MACHINE) {
+ var elt = MACHINE.env.pop();
+ var outputPort =
+ MACHINE.params.currentOutputPort;
+ if (elt !== undefined) {
+ outputPort.write(MACHINE, elt);
+ outputPort.write(MACHINE, "\n");
+ }
+ var frame = MACHINE.control.pop();
+ return frame.label(MACHINE);
+ },
+ 1,
+ [],
+ "printer")
};
@@ -222,7 +225,19 @@
var StandardOutputPort = function() {};
StandardOutputPort.prototype = heir(OutputPort.prototype);
StandardOutputPort.prototype.write = function(MACHINE, v) {
- MACHINE.params['currentDisplayer'](v);
+ var domNode;
+ // TODO: v must be coerced into a DOMNode in a more systematic way.
+ // This function may need to be a Closure.
+ if(typeof(v) === 'string' ||
+ typeof(v) === 'number' ||
+ typeof(v) === 'boolean' ||
+ typeof(v) === 'null' ||
+ typeof(v) === 'undefined') {
+ domNode = $('').text(String(v)).css('white-space', 'pre');
+ } else {
+ domNode = $('').text(String(v)).css('white-space', 'pre');
+ }
+ MACHINE.params['currentDisplayer'](domNode);
};